about summary refs log tree commit diff
diff options
context:
space:
mode:
authorFrederik Rietdijk <fridh@fridh.nl>2017-05-07 12:55:45 +0200
committerFrederik Rietdijk <fridh@fridh.nl>2017-05-07 12:56:09 +0200
commitef4442e827af928a3fd394cb0731b554a31e8d5b (patch)
tree4aa8f846f6a3074b4dc99fb16dd14bdc78ac3dd6
parent024ddb32a7137c81c0e86ba59876c0cf4d5425e7 (diff)
Python: replace requests2 with requests tree-wide
See f63eb5857352705665411130d4f1638d55dd8c58

The `requests2` attribute now throws an error informing that `requests`
should be used instead.
-rw-r--r--doc/languages-frameworks/python.md4
-rw-r--r--pkgs/applications/audio/mopidy-gmusic/default.nix2
-rw-r--r--pkgs/applications/audio/mopidy/default.nix2
-rw-r--r--pkgs/applications/gis/qgis/default.nix2
-rw-r--r--pkgs/applications/misc/buku/default.nix2
-rw-r--r--pkgs/applications/misc/haxor-news/default.nix2
-rw-r--r--pkgs/applications/misc/octoprint/default.nix2
-rw-r--r--pkgs/applications/misc/rtv/default.nix2
-rw-r--r--pkgs/applications/misc/toot/default.nix2
-rw-r--r--pkgs/applications/networking/errbot/default.nix2
-rw-r--r--pkgs/applications/networking/flexget/default.nix2
-rw-r--r--pkgs/applications/networking/sync/acd_cli/default.nix4
-rw-r--r--pkgs/applications/office/watson/default.nix2
-rw-r--r--pkgs/applications/version-management/git-review/default.nix2
-rw-r--r--pkgs/applications/video/streamlink/default.nix2
-rw-r--r--pkgs/applications/virtualization/openstack/glance.nix2
-rw-r--r--pkgs/applications/virtualization/openstack/keystone.nix2
-rw-r--r--pkgs/applications/virtualization/openstack/neutron.nix2
-rw-r--r--pkgs/applications/virtualization/openstack/nova.nix2
-rw-r--r--pkgs/desktops/gnome-3/3.22/apps/gnome-music/default.nix2
-rw-r--r--pkgs/development/python-modules/coveralls/default.nix4
-rw-r--r--pkgs/development/python-modules/docker.nix4
-rw-r--r--pkgs/development/python-modules/docker_compose.nix4
-rw-r--r--pkgs/development/python-modules/ipython/5.nix4
-rw-r--r--pkgs/development/python-modules/notebook/default.nix4
-rw-r--r--pkgs/development/python-modules/plotly/default.nix4
-rw-r--r--pkgs/development/python-modules/pyrax.nix4
-rw-r--r--pkgs/development/python-modules/pytest-httpbin/default.nix4
-rw-r--r--pkgs/development/python-modules/rackspace-novaclient.nix4
-rw-r--r--pkgs/development/python-modules/requests-oauthlib.nix4
-rw-r--r--pkgs/development/python-modules/treq/default.nix4
-rw-r--r--pkgs/development/tools/backblaze-b2/default.nix2
-rw-r--r--pkgs/development/tools/build-managers/conan/default.nix2
-rw-r--r--pkgs/servers/inginious/default.nix2
-rw-r--r--pkgs/servers/matrix-synapse/default.nix2
-rw-r--r--pkgs/tools/audio/beets/default.nix2
-rw-r--r--pkgs/tools/backup/s3ql/default.nix2
-rw-r--r--pkgs/tools/misc/asciinema/default.nix2
-rw-r--r--pkgs/tools/misc/kargo/default.nix2
-rw-r--r--pkgs/tools/misc/svtplay-dl/default.nix4
-rw-r--r--pkgs/tools/misc/system-config-printer/default.nix2
-rw-r--r--pkgs/tools/misc/vdirsyncer/default.nix2
-rw-r--r--pkgs/tools/networking/dd-agent/default.nix4
-rw-r--r--pkgs/tools/networking/httpie/default.nix2
-rw-r--r--pkgs/tools/networking/linkchecker/default.nix4
-rw-r--r--pkgs/tools/networking/mitmproxy/default.nix2
-rw-r--r--pkgs/tools/networking/urlwatch/default.nix2
-rw-r--r--pkgs/tools/package-management/nox/default.nix2
-rw-r--r--pkgs/tools/security/vulnix/default.nix2
-rw-r--r--pkgs/top-level/all-packages.nix2
-rw-r--r--pkgs/top-level/python-packages.nix207
51 files changed, 170 insertions, 169 deletions
diff --git a/doc/languages-frameworks/python.md b/doc/languages-frameworks/python.md
index b127ba2faaeef..d9306ae56bd54 100644
--- a/doc/languages-frameworks/python.md
+++ b/doc/languages-frameworks/python.md
@@ -580,7 +580,7 @@ running `nix-shell` with the following `shell.nix`
 with import <nixpkgs> {};
 
 (python3.buildEnv.override {
-  extraLibs = with python3Packages; [ numpy requests2 ];
+  extraLibs = with python3Packages; [ numpy requests ];
 }).env
 ```
 
@@ -622,7 +622,7 @@ attribute. The `shell.nix` file from the previous section can thus be also writt
 ```nix
 with import <nixpkgs> {};
 
-(python33.withPackages (ps: [ps.numpy ps.requests2])).env
+(python33.withPackages (ps: [ps.numpy ps.requests])).env
 ```
 
 In contrast to `python.buildEnv`, `python.withPackages` does not support the more advanced options
diff --git a/pkgs/applications/audio/mopidy-gmusic/default.nix b/pkgs/applications/audio/mopidy-gmusic/default.nix
index 850e7abaef000..ab2a23b1994ce 100644
--- a/pkgs/applications/audio/mopidy-gmusic/default.nix
+++ b/pkgs/applications/audio/mopidy-gmusic/default.nix
@@ -11,7 +11,7 @@ pythonPackages.buildPythonApplication rec {
 
   propagatedBuildInputs = [
     mopidy
-    pythonPackages.requests2
+    pythonPackages.requests
     pythonPackages.gmusicapi
     pythonPackages.cachetools
   ];
diff --git a/pkgs/applications/audio/mopidy/default.nix b/pkgs/applications/audio/mopidy/default.nix
index 7dae614a8f780..7de8f6941c2b8 100644
--- a/pkgs/applications/audio/mopidy/default.nix
+++ b/pkgs/applications/audio/mopidy/default.nix
@@ -22,7 +22,7 @@ pythonPackages.buildPythonApplication rec {
   ];
 
   propagatedBuildInputs = with pythonPackages; [
-    gst-python pygobject3 pykka tornado requests2 dbus-python
+    gst-python pygobject3 pykka tornado requests dbus-python
   ];
 
   # There are no tests
diff --git a/pkgs/applications/gis/qgis/default.nix b/pkgs/applications/gis/qgis/default.nix
index d7dbaeb1fc21e..b8c9d1718143a 100644
--- a/pkgs/applications/gis/qgis/default.nix
+++ b/pkgs/applications/gis/qgis/default.nix
@@ -10,7 +10,7 @@ stdenv.mkDerivation rec {
   buildInputs = [ gdal qt4 flex openssl bison proj geos xlibsWrapper sqlite gsl qwt qscintilla
     fcgi libspatialindex libspatialite postgresql qjson qca2 txt2tags ] ++
     (stdenv.lib.optional withGrass grass) ++
-    (with python2Packages; [ numpy psycopg2 requests2 python2Packages.qscintilla sip ]);
+    (with python2Packages; [ numpy psycopg2 requests python2Packages.qscintilla sip ]);
 
   nativeBuildInputs = [ cmake makeWrapper ];
 
diff --git a/pkgs/applications/misc/buku/default.nix b/pkgs/applications/misc/buku/default.nix
index 1ee68b55aa731..117313a3266b6 100644
--- a/pkgs/applications/misc/buku/default.nix
+++ b/pkgs/applications/misc/buku/default.nix
@@ -15,7 +15,7 @@ with pythonPackages; buildPythonApplication rec {
   propagatedBuildInputs = [
     cryptography
     beautifulsoup4
-    requests2
+    requests
     urllib3
   ];
 
diff --git a/pkgs/applications/misc/haxor-news/default.nix b/pkgs/applications/misc/haxor-news/default.nix
index d2acbbfea5b67..481e210795182 100644
--- a/pkgs/applications/misc/haxor-news/default.nix
+++ b/pkgs/applications/misc/haxor-news/default.nix
@@ -12,7 +12,7 @@ pythonPackages.buildPythonApplication rec {
   propagatedBuildInputs = with pythonPackages; [
     click
     colorama
-    requests2
+    requests
     pygments
     prompt_toolkit
     six
diff --git a/pkgs/applications/misc/octoprint/default.nix b/pkgs/applications/misc/octoprint/default.nix
index 661f8dfe48f09..45b704a5f47a9 100644
--- a/pkgs/applications/misc/octoprint/default.nix
+++ b/pkgs/applications/misc/octoprint/default.nix
@@ -65,7 +65,7 @@ in pythonPackages.buildPythonApplication rec {
 
   # We need old Tornado
   propagatedBuildInputs = with pythonPackages; [
-    awesome-slugify flask_assets rsa requests2 pkginfo watchdog
+    awesome-slugify flask_assets rsa requests pkginfo watchdog
     semantic-version flask_principal werkzeug flaskbabel tornado
     psutil pyserial flask_login netaddr markdown sockjs-tornado
     pylru pyyaml sarge feedparser netifaces click websocket_client
diff --git a/pkgs/applications/misc/rtv/default.nix b/pkgs/applications/misc/rtv/default.nix
index e8b3eeda01ad0..fbf9a9335675a 100644
--- a/pkgs/applications/misc/rtv/default.nix
+++ b/pkgs/applications/misc/rtv/default.nix
@@ -35,7 +35,7 @@ buildPythonApplication rec {
     kitchen
     mailcap-fix
     mccabe
-    requests2
+    requests
     six
     tornado
     pyyaml
diff --git a/pkgs/applications/misc/toot/default.nix b/pkgs/applications/misc/toot/default.nix
index 5a3be423cd2fd..4f66d7167e108 100644
--- a/pkgs/applications/misc/toot/default.nix
+++ b/pkgs/applications/misc/toot/default.nix
@@ -12,7 +12,7 @@ pythonPackages.buildPythonApplication rec {
   };
 
   propagatedBuildInputs = with pythonPackages;
-    [ requests2 beautifulsoup4 future ];
+    [ requests beautifulsoup4 future ];
 
   meta = with stdenv.lib; {
     description = "Mastodon CLI interface";
diff --git a/pkgs/applications/networking/errbot/default.nix b/pkgs/applications/networking/errbot/default.nix
index f37f10d5209bf..e2b5844429f1a 100644
--- a/pkgs/applications/networking/errbot/default.nix
+++ b/pkgs/applications/networking/errbot/default.nix
@@ -20,7 +20,7 @@ pythonPackages.buildPythonApplication rec {
   ];
 
   propagatedBuildInputs = with pythonPackages; [
-    webtest bottle threadpool rocket-errbot requests2 jinja2
+    webtest bottle threadpool rocket-errbot requests jinja2
     pyopenssl colorlog Yapsy markdown ansi pygments dns pep8
     daemonize pygments-markdown-lexer telegram irc slackclient
     pyside sleekxmpp hypchat pytest
diff --git a/pkgs/applications/networking/flexget/default.nix b/pkgs/applications/networking/flexget/default.nix
index 64afbdac1b94a..6c3731b82a413 100644
--- a/pkgs/applications/networking/flexget/default.nix
+++ b/pkgs/applications/networking/flexget/default.nix
@@ -41,7 +41,7 @@ buildPythonApplication rec {
   propagatedBuildInputs = [
     feedparser sqlalchemy pyyaml
     beautifulsoup4 html5lib PyRSS2Gen pynzb
-    rpyc jinja2 requests2 dateutil jsonschema
+    rpyc jinja2 requests dateutil jsonschema
     pathpy guessit APScheduler
     terminaltables colorclass
     cherrypy flask flask-restful flask-restplus_0_8
diff --git a/pkgs/applications/networking/sync/acd_cli/default.nix b/pkgs/applications/networking/sync/acd_cli/default.nix
index bb767da94d067..e4ba29d3a9f88 100644
--- a/pkgs/applications/networking/sync/acd_cli/default.nix
+++ b/pkgs/applications/networking/sync/acd_cli/default.nix
@@ -1,5 +1,5 @@
 { stdenv, fetchFromGitHub, buildPythonApplication, fuse
-, appdirs, colorama, dateutil, requests2, requests_toolbelt
+, appdirs, colorama, dateutil, requests, requests_toolbelt
 , fusepy, sqlalchemy }:
 
 buildPythonApplication rec {
@@ -16,7 +16,7 @@ buildPythonApplication rec {
     sha256 = "0a0fr632l24a3jmgla3b1vcm50ayfa9hdbp677ch1chwj5dq4zfp";
   };
 
-  propagatedBuildInputs = [ appdirs colorama dateutil fusepy requests2
+  propagatedBuildInputs = [ appdirs colorama dateutil fusepy requests
                             requests_toolbelt sqlalchemy ];
 
   makeWrapperArgs = [ "--prefix LIBFUSE_PATH : ${fuse}/lib/libfuse.so" ];
diff --git a/pkgs/applications/office/watson/default.nix b/pkgs/applications/office/watson/default.nix
index e3d04285d21b5..a1fcfd5de700d 100644
--- a/pkgs/applications/office/watson/default.nix
+++ b/pkgs/applications/office/watson/default.nix
@@ -16,7 +16,7 @@ pythonPackages.buildPythonApplication rec {
     py.test -vs tests
  '';
   checkInputs = with pythonPackages; [ py pytest pytest-datafiles mock pytest-mock pytestrunner ];
-  propagatedBuildInputs = with pythonPackages; [ requests2 click arrow ];
+  propagatedBuildInputs = with pythonPackages; [ requests click arrow ];
 
   meta = with stdenv.lib; {
     homepage = https://tailordev.github.io/Watson/;
diff --git a/pkgs/applications/version-management/git-review/default.nix b/pkgs/applications/version-management/git-review/default.nix
index de934db5f3bac..080894bc80e19 100644
--- a/pkgs/applications/version-management/git-review/default.nix
+++ b/pkgs/applications/version-management/git-review/default.nix
@@ -13,7 +13,7 @@ pythonPackages.buildPythonApplication rec {
     sha256 = "aa594690ed586041a524d6e5ae76152cbd53d4f03a98b20b213d15cecbe128ce";
   };
 
-  propagatedBuildInputs = [ pythonPackages.pbr pythonPackages.requests2 pythonPackages.argparse pythonPackages.setuptools ];
+  propagatedBuildInputs = [ pythonPackages.pbr pythonPackages.requests pythonPackages.argparse pythonPackages.setuptools ];
 
   # Don't do tests because they require gerrit which is not packaged
   doCheck = false;
diff --git a/pkgs/applications/video/streamlink/default.nix b/pkgs/applications/video/streamlink/default.nix
index 163218c0478bf..4891592bc7e4b 100644
--- a/pkgs/applications/video/streamlink/default.nix
+++ b/pkgs/applications/video/streamlink/default.nix
@@ -13,7 +13,7 @@ pythonPackages.buildPythonApplication rec {
 
   buildInputs = with pythonPackages; [ pytest mock ];
 
-  propagatedBuildInputs = (with pythonPackages; [ pycryptodome requests2 iso-639 iso3166 ]) ++ [ rtmpdump ffmpeg ];
+  propagatedBuildInputs = (with pythonPackages; [ pycryptodome requests iso-639 iso3166 ]) ++ [ rtmpdump ffmpeg ];
 
   meta = with stdenv.lib; {
     homepage = https://github.com/streamlink/streamlink;
diff --git a/pkgs/applications/virtualization/openstack/glance.nix b/pkgs/applications/virtualization/openstack/glance.nix
index f78e5da9a8c0c..21cb4906d0347 100644
--- a/pkgs/applications/virtualization/openstack/glance.nix
+++ b/pkgs/applications/virtualization/openstack/glance.nix
@@ -26,7 +26,7 @@ python2Packages.buildPythonApplication rec {
   ];
 
   buildInputs = with python2Packages; [
-    Babel coverage fixtures mox3 mock oslosphinx requests2 testrepository pep8
+    Babel coverage fixtures mox3 mock oslosphinx requests testrepository pep8
     testresources testscenarios testtools psutil_1 oslotest psycopg2
     sqlite which strace
   ];
diff --git a/pkgs/applications/virtualization/openstack/keystone.nix b/pkgs/applications/virtualization/openstack/keystone.nix
index 3a5941880795f..39c54f0d204b0 100644
--- a/pkgs/applications/virtualization/openstack/keystone.nix
+++ b/pkgs/applications/virtualization/openstack/keystone.nix
@@ -30,7 +30,7 @@ python2Packages.buildPythonApplication rec {
 
   buildInputs = with python2Packages; [
     coverage fixtures mock subunit tempest-lib testtools testrepository
-    ldap ldappool webtest requests2 oslotest pep8 pymongo which
+    ldap ldappool webtest requests oslotest pep8 pymongo which
   ];
 
   makeWrapperArgs = ["--prefix PATH : '${openssl.bin}/bin:$PATH'"];
diff --git a/pkgs/applications/virtualization/openstack/neutron.nix b/pkgs/applications/virtualization/openstack/neutron.nix
index c1ee231d97f58..9ee586cf04091 100644
--- a/pkgs/applications/virtualization/openstack/neutron.nix
+++ b/pkgs/applications/virtualization/openstack/neutron.nix
@@ -14,7 +14,7 @@ python2Packages.buildPythonApplication rec {
 
   # https://github.com/openstack/neutron/blob/stable/liberty/requirements.txt
   propagatedBuildInputs = with python2Packages; [
-   pbr paste PasteDeploy routes debtcollector eventlet greenlet httplib2 requests2
+   pbr paste PasteDeploy routes debtcollector eventlet greenlet httplib2 requests
    jinja2 keystonemiddleware netaddr retrying sqlalchemy webob alembic six
    stevedore pecan ryu networking-hyperv MySQL_python
 
diff --git a/pkgs/applications/virtualization/openstack/nova.nix b/pkgs/applications/virtualization/openstack/nova.nix
index 219026f1e0fb8..ef3eb2fb08429 100644
--- a/pkgs/applications/virtualization/openstack/nova.nix
+++ b/pkgs/applications/virtualization/openstack/nova.nix
@@ -24,7 +24,7 @@ python2Packages.buildPythonApplication rec {
   propagatedBuildInputs = with python2Packages; [
     pbr sqlalchemy boto decorator eventlet jinja2 lxml routes cryptography
     webob greenlet PasteDeploy paste prettytable sqlalchemy_migrate netaddr
-    netifaces paramiko Babel iso8601 jsonschema keystoneclient requests2 six
+    netifaces paramiko Babel iso8601 jsonschema keystoneclient requests six
     stevedore websockify rfc3986 os-brick psutil_1 alembic psycopg2 pymysql
     keystonemiddleware MySQL_python
 
diff --git a/pkgs/desktops/gnome-3/3.22/apps/gnome-music/default.nix b/pkgs/desktops/gnome-3/3.22/apps/gnome-music/default.nix
index ea8f15fd4e59f..4f11e7a284387 100644
--- a/pkgs/desktops/gnome-3/3.22/apps/gnome-music/default.nix
+++ b/pkgs/desktops/gnome-3/3.22/apps/gnome-music/default.nix
@@ -11,7 +11,7 @@ stdenv.mkDerivation rec {
   buildInputs = [ pkgconfig gtk3 glib intltool itstool gnome3.libmediaart
                   gdk_pixbuf gnome3.defaultIconTheme librsvg python3Packages.python
                   gnome3.grilo gnome3.grilo-plugins gnome3.totem-pl-parser libxml2 libnotify
-                  python3Packages.pycairo python3Packages.dbus-python python3Packages.requests2
+                  python3Packages.pycairo python3Packages.dbus-python python3Packages.requests
                   python3Packages.pygobject3 gst_all_1.gstreamer gst_all_1.gst-plugins-base
                   gst_all_1.gst-plugins-good gst_all_1.gst-plugins-bad wrapGAppsHook
                   gnome3.gsettings_desktop_schemas makeWrapper tracker ];
diff --git a/pkgs/development/python-modules/coveralls/default.nix b/pkgs/development/python-modules/coveralls/default.nix
index 59f66f36d8768..57431c2c2c252 100644
--- a/pkgs/development/python-modules/coveralls/default.nix
+++ b/pkgs/development/python-modules/coveralls/default.nix
@@ -6,7 +6,7 @@
 , sh
 , coverage
 , docopt
-, requests2
+, requests
 , git
 }:
 
@@ -38,7 +38,7 @@ buildPythonPackage rec {
   propagatedBuildInputs = [
     coverage
     docopt
-    requests2
+    requests
   ];
 
   meta = {
diff --git a/pkgs/development/python-modules/docker.nix b/pkgs/development/python-modules/docker.nix
index 12c9aac4c23db..84c7b5ff38b59 100644
--- a/pkgs/development/python-modules/docker.nix
+++ b/pkgs/development/python-modules/docker.nix
@@ -1,5 +1,5 @@
 { stdenv, buildPythonPackage, fetchurl
-, six, requests2, websocket_client
+, six, requests, websocket_client
 , ipaddress, backports_ssl_match_hostname, docker_pycreds
 }:
 buildPythonPackage rec {
@@ -13,7 +13,7 @@ buildPythonPackage rec {
 
   propagatedBuildInputs = [
     six
-    requests2
+    requests
     websocket_client
     ipaddress
     backports_ssl_match_hostname
diff --git a/pkgs/development/python-modules/docker_compose.nix b/pkgs/development/python-modules/docker_compose.nix
index c21b69e1643eb..9af95f72598f0 100644
--- a/pkgs/development/python-modules/docker_compose.nix
+++ b/pkgs/development/python-modules/docker_compose.nix
@@ -1,7 +1,7 @@
 { stdenv, buildPythonApplication, fetchurl, pythonOlder
 , mock, pytest, nose
 , pyyaml, backports_ssl_match_hostname, colorama, docopt
-, dockerpty, docker, ipaddress, jsonschema, requests2
+, dockerpty, docker, ipaddress, jsonschema, requests
 , six, texttable, websocket_client, cached-property
 , enum34, functools32
 }:
@@ -19,7 +19,7 @@ buildPythonApplication rec {
   buildInputs = [ mock pytest nose ];
   propagatedBuildInputs = [
     pyyaml backports_ssl_match_hostname colorama dockerpty docker
-    ipaddress jsonschema requests2 six texttable websocket_client
+    ipaddress jsonschema requests six texttable websocket_client
     docopt cached-property
   ] ++
     stdenv.lib.optional (pythonOlder "3.4") enum34 ++
diff --git a/pkgs/development/python-modules/ipython/5.nix b/pkgs/development/python-modules/ipython/5.nix
index 011c86652902a..b25039cc71e89 100644
--- a/pkgs/development/python-modules/ipython/5.nix
+++ b/pkgs/development/python-modules/ipython/5.nix
@@ -17,7 +17,7 @@
 , decorator
 , pathlib2
 , pickleshare
-, requests2
+, requests
 , simplegeneric
 , traitlets
 , prompt_toolkit
@@ -45,7 +45,7 @@ buildPythonPackage rec {
 
   propagatedBuildInputs = [
     backports_shutil_get_terminal_size decorator pickleshare prompt_toolkit
-    simplegeneric traitlets requests2 pathlib2 pexpect
+    simplegeneric traitlets requests pathlib2 pexpect
   ] ++ lib.optionals stdenv.isDarwin [ appnope ];
 
   LC_ALL="en_US.UTF-8";
diff --git a/pkgs/development/python-modules/notebook/default.nix b/pkgs/development/python-modules/notebook/default.nix
index 0fa94854640b5..3a24c5566bf04 100644
--- a/pkgs/development/python-modules/notebook/default.nix
+++ b/pkgs/development/python-modules/notebook/default.nix
@@ -15,7 +15,7 @@
 , nbconvert
 , ipykernel
 , terminado
-, requests2
+, requests
 , pexpect
 }:
 
@@ -34,7 +34,7 @@ buildPythonPackage rec {
   buildInputs = [nose glibcLocales]  ++ lib.optionals isPy27 [mock];
 
   propagatedBuildInputs = [jinja2 tornado ipython_genutils traitlets jupyter_core
-    jupyter_client nbformat nbconvert ipykernel terminado requests2 pexpect ];
+    jupyter_client nbformat nbconvert ipykernel terminado requests pexpect ];
 
   checkPhase = ''
     nosetests -v
diff --git a/pkgs/development/python-modules/plotly/default.nix b/pkgs/development/python-modules/plotly/default.nix
index 3c2e78ac1f1f0..6e5627a58ca89 100644
--- a/pkgs/development/python-modules/plotly/default.nix
+++ b/pkgs/development/python-modules/plotly/default.nix
@@ -4,7 +4,7 @@
 , decorator
 , nbformat
 , pytz
-, requests2
+, requests
 , six
 }:
 
@@ -22,7 +22,7 @@ buildPythonPackage rec {
     decorator
     nbformat
     pytz
-    requests2
+    requests
     six
   ];
 
diff --git a/pkgs/development/python-modules/pyrax.nix b/pkgs/development/python-modules/pyrax.nix
index 0abf54f03fe14..87c0c3db264fd 100644
--- a/pkgs/development/python-modules/pyrax.nix
+++ b/pkgs/development/python-modules/pyrax.nix
@@ -1,4 +1,4 @@
-{ lib, buildPythonPackage, fetchurl, requests2, novaclient, keyring,
+{ lib, buildPythonPackage, fetchurl, requests, novaclient, keyring,
   rackspace-novaclient, six, isPy3k, pytest, glibcLocales }:
 buildPythonPackage rec {
   name = "pyrax-1.9.8";
@@ -15,7 +15,7 @@ buildPythonPackage rec {
     '';
 
   disabled = isPy3k;
-  propagatedBuildInputs = [ requests2 novaclient keyring rackspace-novaclient six ];
+  propagatedBuildInputs = [ requests novaclient keyring rackspace-novaclient six ];
 
   LC_ALL = "en_US.UTF-8";
   buildInputs = [ pytest glibcLocales ];
diff --git a/pkgs/development/python-modules/pytest-httpbin/default.nix b/pkgs/development/python-modules/pytest-httpbin/default.nix
index a31c9ba35bbe3..34a2bf7e31cb7 100644
--- a/pkgs/development/python-modules/pytest-httpbin/default.nix
+++ b/pkgs/development/python-modules/pytest-httpbin/default.nix
@@ -6,7 +6,7 @@
 , decorator
 , httpbin
 , six
-, requests2
+, requests
 }:
 
 buildPythonPackage rec {
@@ -25,7 +25,7 @@ buildPythonPackage rec {
   '';
 
   buildInputs = [ pytest ];
-  propagatedBuildInputs = [ flask decorator httpbin six requests2 ];
+  propagatedBuildInputs = [ flask decorator httpbin six requests ];
 
   meta = {
     description = "Easily test your HTTP library against a local copy of httpbin.org";
diff --git a/pkgs/development/python-modules/rackspace-novaclient.nix b/pkgs/development/python-modules/rackspace-novaclient.nix
index 0eaed7e36fd9e..144b61c9b9a57 100644
--- a/pkgs/development/python-modules/rackspace-novaclient.nix
+++ b/pkgs/development/python-modules/rackspace-novaclient.nix
@@ -1,4 +1,4 @@
-{ buildPythonPackage, fetchurl, isPy3k, requests2, novaclient, six, lib }:
+{ buildPythonPackage, fetchurl, isPy3k, requests, novaclient, six, lib }:
 let
 os-virtual-interfacesv2-python-novaclient-ext = buildPythonPackage rec {
   name = "os_virtual_interfacesv2_python_novaclient_ext-0.20";
@@ -129,7 +129,7 @@ buildPythonPackage rec {
 
   disabled = isPy3k;
   propagatedBuildInputs = [
-    requests2
+    requests
     novaclient
     six
     # extensions
diff --git a/pkgs/development/python-modules/requests-oauthlib.nix b/pkgs/development/python-modules/requests-oauthlib.nix
index a353ebd39d9b2..62ecf134b49ef 100644
--- a/pkgs/development/python-modules/requests-oauthlib.nix
+++ b/pkgs/development/python-modules/requests-oauthlib.nix
@@ -1,5 +1,5 @@
 { stdenv, buildPythonPackage, fetchurl
-, oauthlib, requests2 }:
+, oauthlib, requests }:
 
 buildPythonPackage rec {
   version = "0.7.0";
@@ -11,7 +11,7 @@ buildPythonPackage rec {
   };
 
   doCheck = false;        # Internet tests fail when building in chroot
-  propagatedBuildInputs = [ oauthlib requests2 ];
+  propagatedBuildInputs = [ oauthlib requests ];
 
   meta = with stdenv.lib; {
     description = "OAuthlib authentication support for Requests";
diff --git a/pkgs/development/python-modules/treq/default.nix b/pkgs/development/python-modules/treq/default.nix
index 37f9e3324c7ed..14a2ac9cb92d8 100644
--- a/pkgs/development/python-modules/treq/default.nix
+++ b/pkgs/development/python-modules/treq/default.nix
@@ -1,4 +1,4 @@
-{ stdenv, fetchurl, buildPythonPackage, service-identity, requests2,
+{ stdenv, fetchurl, buildPythonPackage, service-identity, requests,
   six, mock, twisted, incremental, coreutils, gnumake, pep8, sphinx,
   openssl, pyopenssl }:
 
@@ -19,7 +19,7 @@ buildPythonPackage rec {
 
   propagatedBuildInputs = [
     service-identity
-    requests2
+    requests
     twisted
     incremental
     sphinx
diff --git a/pkgs/development/tools/backblaze-b2/default.nix b/pkgs/development/tools/backblaze-b2/default.nix
index 850affb061080..94960e1b74da5 100644
--- a/pkgs/development/tools/backblaze-b2/default.nix
+++ b/pkgs/development/tools/backblaze-b2/default.nix
@@ -11,7 +11,7 @@ pythonPackages.buildPythonApplication rec {
     sha256 = "1gl1z7zg3s1xgx45i6b1bvx9iwviiiinl4my00h66qkhrw7ag8p1";
   };
 
-  propagatedBuildInputs = with pythonPackages; [ futures requests2 six tqdm ];
+  propagatedBuildInputs = with pythonPackages; [ futures requests six tqdm ];
 
   checkPhase = ''
     python test_b2_command_line.py test
diff --git a/pkgs/development/tools/build-managers/conan/default.nix b/pkgs/development/tools/build-managers/conan/default.nix
index 417e492f7d0bc..69cc2db3ff280 100644
--- a/pkgs/development/tools/build-managers/conan/default.nix
+++ b/pkgs/development/tools/build-managers/conan/default.nix
@@ -11,7 +11,7 @@ pythonPackages.buildPythonApplication rec {
   };
 
   propagatedBuildInputs = with pythonPackages; [
-    requests2 fasteners pyyaml pyjwt colorama patch
+    requests fasteners pyyaml pyjwt colorama patch
     bottle pluginbase six distro pylint node-semver
   ];
 
diff --git a/pkgs/servers/inginious/default.nix b/pkgs/servers/inginious/default.nix
index ae3347c9671ad..e09a9f740982d 100644
--- a/pkgs/servers/inginious/default.nix
+++ b/pkgs/servers/inginious/default.nix
@@ -37,7 +37,7 @@ in pythonPackages.buildPythonApplication rec {
   '';
 
   propagatedBuildInputs = with pythonPackages; [
-    requests2
+    requests
     cgroup-utils docker_1_7_2 docutils PyLTI mock pygments
     pymongo pyyaml rpyc sh simpleldap sphinx_rtd_theme tidylib
     websocket_client watchdog webpy-custom flup
diff --git a/pkgs/servers/matrix-synapse/default.nix b/pkgs/servers/matrix-synapse/default.nix
index 85ebb5a80431d..f6b21149a8c53 100644
--- a/pkgs/servers/matrix-synapse/default.nix
+++ b/pkgs/servers/matrix-synapse/default.nix
@@ -37,7 +37,7 @@ in pythonPackages.buildPythonApplication rec {
 
   propagatedBuildInputs = with pythonPackages; [
     blist canonicaljson daemonize dateutil frozendict pillow pybcrypt pyasn1
-    pydenticon pymacaroons-pynacl pynacl pyopenssl pysaml2 pytz requests2
+    pydenticon pymacaroons-pynacl pynacl pyopenssl pysaml2 pytz requests
     signedjson systemd twisted ujson unpaddedbase64 pyyaml
     matrix-angular-sdk bleach netaddr jinja2 psycopg2
     psutil msgpack lxml matrix-synapse-ldap3
diff --git a/pkgs/tools/audio/beets/default.nix b/pkgs/tools/audio/beets/default.nix
index 69f0d89e7f850..c1418d152dd2d 100644
--- a/pkgs/tools/audio/beets/default.nix
+++ b/pkgs/tools/audio/beets/default.nix
@@ -100,7 +100,7 @@ in pythonPackages.buildPythonApplication rec {
     ++ optional (enableFetchart
               || enableEmbyupdate
               || enableAcousticbrainz)
-                                   pythonPackages.requests2
+                                   pythonPackages.requests
     ++ optional enableConvert      ffmpeg
     ++ optional enableDiscogs      pythonPackages.discogs_client
     ++ optional enableKeyfinder    keyfinder-cli
diff --git a/pkgs/tools/backup/s3ql/default.nix b/pkgs/tools/backup/s3ql/default.nix
index a90738d39a4c9..05bf38613efd6 100644
--- a/pkgs/tools/backup/s3ql/default.nix
+++ b/pkgs/tools/backup/s3ql/default.nix
@@ -12,7 +12,7 @@ python3Packages.buildPythonApplication rec {
 
   buildInputs = [ which ]; # tests will fail without which
   propagatedBuildInputs = with python3Packages; [
-    sqlite apsw pycrypto requests2 defusedxml dugong llfuse
+    sqlite apsw pycrypto requests defusedxml dugong llfuse
     cython pytest pytest-catchlog
   ];
 
diff --git a/pkgs/tools/misc/asciinema/default.nix b/pkgs/tools/misc/asciinema/default.nix
index 4b228efee9e1f..4d6e90a347e73 100644
--- a/pkgs/tools/misc/asciinema/default.nix
+++ b/pkgs/tools/misc/asciinema/default.nix
@@ -7,7 +7,7 @@ in pythonPackages.buildPythonApplication rec {
   version = "1.4.0";
 
   buildInputs = with pythonPackages; [ nose ];
-  propagatedBuildInputs = with pythonPackages; [ requests2 ];
+  propagatedBuildInputs = with pythonPackages; [ requests ];
 
   src = fetchFromGitHub {
     owner = "asciinema";
diff --git a/pkgs/tools/misc/kargo/default.nix b/pkgs/tools/misc/kargo/default.nix
index 734d8fb78e239..4c390f1e80e26 100644
--- a/pkgs/tools/misc/kargo/default.nix
+++ b/pkgs/tools/misc/kargo/default.nix
@@ -20,7 +20,7 @@ python2Packages.buildPythonApplication rec {
     markupsafe
     netaddr
     pyasn1
-    requests2
+    requests
     setuptools
   ];
 
diff --git a/pkgs/tools/misc/svtplay-dl/default.nix b/pkgs/tools/misc/svtplay-dl/default.nix
index a2d6caa153525..8d65f253c9b4d 100644
--- a/pkgs/tools/misc/svtplay-dl/default.nix
+++ b/pkgs/tools/misc/svtplay-dl/default.nix
@@ -2,7 +2,7 @@
 , rtmpdump, substituteAll }:
 
 let
-  inherit (pythonPackages) python nose pycrypto requests2 mock;
+  inherit (pythonPackages) python nose pycrypto requests mock;
 in stdenv.mkDerivation rec {
   name = "svtplay-dl-${version}";
   version = "1.9.3";
@@ -14,7 +14,7 @@ in stdenv.mkDerivation rec {
     sha256 = "14qksi1svi89niffykxg47kay013byls6bnhkrkzkanq04075lmw";
   };
 
-  pythonPaths = [ pycrypto requests2 ];
+  pythonPaths = [ pycrypto requests ];
   buildInputs = [ python perl nose mock rtmpdump makeWrapper ] ++ pythonPaths;
   nativeBuildInputs = [ zip ];
 
diff --git a/pkgs/tools/misc/system-config-printer/default.nix b/pkgs/tools/misc/system-config-printer/default.nix
index 0d66ef66b4859..04aa838270cda 100644
--- a/pkgs/tools/misc/system-config-printer/default.nix
+++ b/pkgs/tools/misc/system-config-printer/default.nix
@@ -29,7 +29,7 @@ stdenv.mkDerivation rec {
   nativeBuildInputs = [ wrapGAppsHook ];
 
   pythonPath = with pythonPackages;
-    [ pycups pycurl dbus-python pygobject3 requests2 pycairo pythonPackages.pycurl ];
+    [ pycups pycurl dbus-python pygobject3 requests pycairo pythonPackages.pycurl ];
 
   configureFlags =
     [ "--with-udev-rules"
diff --git a/pkgs/tools/misc/vdirsyncer/default.nix b/pkgs/tools/misc/vdirsyncer/default.nix
index d1fa9d5bea6d1..731a194cc6a26 100644
--- a/pkgs/tools/misc/vdirsyncer/default.nix
+++ b/pkgs/tools/misc/vdirsyncer/default.nix
@@ -17,7 +17,7 @@ pythonPackages.buildPythonApplication rec {
   propagatedBuildInputs = with pythonPackages; [
     click click-log click-threading
     requests_toolbelt
-    requests2
+    requests
     atomicwrites
   ];
 
diff --git a/pkgs/tools/networking/dd-agent/default.nix b/pkgs/tools/networking/dd-agent/default.nix
index e9a70b17130c2..d1171a3c8355c 100644
--- a/pkgs/tools/networking/dd-agent/default.nix
+++ b/pkgs/tools/networking/dd-agent/default.nix
@@ -15,7 +15,7 @@ let
 
     propagatedBuildInputs = with pythonPackages; [
       six
-      requests2
+      requests
       websocket_client
       ipaddress
       backports_ssl_match_hostname
@@ -42,7 +42,7 @@ in stdenv.mkDerivation rec {
     python
     unzip
     makeWrapper
-    pythonPackages.requests2
+    pythonPackages.requests
     pythonPackages.psycopg2
     pythonPackages.psutil
     pythonPackages.ntplib
diff --git a/pkgs/tools/networking/httpie/default.nix b/pkgs/tools/networking/httpie/default.nix
index 09200f40c9342..84420aa3efb00 100644
--- a/pkgs/tools/networking/httpie/default.nix
+++ b/pkgs/tools/networking/httpie/default.nix
@@ -9,7 +9,7 @@ pythonPackages.buildPythonApplication rec {
     sha256 = "1jsgfkyzzizgfy1b0aicb4cp34d5pwskz9c4a8kf4rq3lrpjw87i";
   };
 
-  propagatedBuildInputs = with pythonPackages; [ pygments requests2 ];
+  propagatedBuildInputs = with pythonPackages; [ pygments requests ];
 
   doCheck = false;
 
diff --git a/pkgs/tools/networking/mitmproxy/default.nix b/pkgs/tools/networking/mitmproxy/default.nix
index dcdcf9b734c0b..83a526a5535ce 100644
--- a/pkgs/tools/networking/mitmproxy/default.nix
+++ b/pkgs/tools/networking/mitmproxy/default.nix
@@ -16,7 +16,7 @@ python3Packages.buildPythonPackage rec {
     blinker click certifi construct cryptography
     cssutils editorconfig h2 html2text hyperframe
     jsbeautifier kaitaistruct passlib pyasn1 pyopenssl
-    pyparsing pyperclip requests2 ruamel_yaml tornado
+    pyparsing pyperclip requests ruamel_yaml tornado
     urwid watchdog brotlipy sortedcontainers
   ];
 
diff --git a/pkgs/tools/networking/urlwatch/default.nix b/pkgs/tools/networking/urlwatch/default.nix
index c1b19f745a3f3..8161f700ce184 100644
--- a/pkgs/tools/networking/urlwatch/default.nix
+++ b/pkgs/tools/networking/urlwatch/default.nix
@@ -15,7 +15,7 @@ python3Packages.buildPythonApplication rec {
     keyring
     minidb
     pyyaml
-    requests2
+    requests
   ];
 
   meta = with stdenv.lib; {
diff --git a/pkgs/tools/package-management/nox/default.nix b/pkgs/tools/package-management/nox/default.nix
index 1184c0194bc76..bba7c3d7fa690 100644
--- a/pkgs/tools/package-management/nox/default.nix
+++ b/pkgs/tools/package-management/nox/default.nix
@@ -15,7 +15,7 @@ pythonPackages.buildPythonApplication rec {
   propagatedBuildInputs = with pythonPackages; [
       dogpile_cache
       click
-      requests2
+      requests
       characteristic
     ];
 
diff --git a/pkgs/tools/security/vulnix/default.nix b/pkgs/tools/security/vulnix/default.nix
index 55defd6809090..a058c2ee1a872 100644
--- a/pkgs/tools/security/vulnix/default.nix
+++ b/pkgs/tools/security/vulnix/default.nix
@@ -27,7 +27,7 @@ in pythonPackages.buildPythonApplication rec{
     colorama
     lxml
     pyyaml
-    requests2
+    requests
     external.zodb
   ]);
 
diff --git a/pkgs/top-level/all-packages.nix b/pkgs/top-level/all-packages.nix
index dfba83589fff2..6c6295ef5c5bc 100644
--- a/pkgs/top-level/all-packages.nix
+++ b/pkgs/top-level/all-packages.nix
@@ -12939,7 +12939,7 @@ with pkgs;
   acd-cli = callPackage ../applications/networking/sync/acd_cli {
     inherit (python35Packages)
       buildPythonApplication appdirs colorama dateutil
-      requests2 requests_toolbelt sqlalchemy fusepy;
+      requests requests_toolbelt sqlalchemy fusepy;
   };
 
   adobe-reader = callPackage_i686 ../applications/misc/adobe-reader { };
diff --git a/pkgs/top-level/python-packages.nix b/pkgs/top-level/python-packages.nix
index 556732dbeabd4..c661b40d58c8a 100644
--- a/pkgs/top-level/python-packages.nix
+++ b/pkgs/top-level/python-packages.nix
@@ -446,7 +446,7 @@ in {
     name = "acme-${version}";
 
     propagatedBuildInputs = with self; [
-      cryptography pyasn1 pyopenssl pyRFC3339 pytz requests2 six werkzeug mock
+      cryptography pyasn1 pyopenssl pyRFC3339 pytz requests six werkzeug mock
       ndg-httpsclient
     ];
 
@@ -524,7 +524,7 @@ in {
       sha256 = "1f32k18ck54adqlgvh6fjhy4yavcyrwy813prjyqppqqq4bn1a09";
     };
 
-    propagatedBuildInputs = with self; [ requests2 pyjwt ];
+    propagatedBuildInputs = with self; [ requests pyjwt ];
 
     meta = {
       description = "Library to make it easy for python application to authenticate to Azure Active Directory (AAD) in order to access AAD protected web resources";
@@ -1613,7 +1613,7 @@ in {
       sha256 = "89c20b2efaaed3c6f56345d55c32a8d4e7d2a16c032d0acb92f8f490c508fe24";
     };
 
-    propagatedBuildInputs = with self; [ dateutil futures pyopenssl requests2 ];
+    propagatedBuildInputs = with self; [ dateutil futures pyopenssl requests ];
 
     meta = {
       description = "Microsoft Azure SDK for Python";
@@ -1665,7 +1665,7 @@ in {
       url = mirror://pypi/a/azure-mgmt-common/azure-mgmt-common-0.20.0.zip;
       sha256 = "1rmzpz3733wv31rsnqpdy4bbafvk5dhbqx7q0xf62dlz7p0i4f66";
     };
-    propagatedBuildInputs = with self; [ azure-common azure-mgmt-nspkg requests2 ];
+    propagatedBuildInputs = with self; [ azure-common azure-mgmt-nspkg requests ];
     postInstall = ''
       echo "__import__('pkg_resources').declare_namespace(__name__)" >> "$out/lib/${python.libPrefix}"/site-packages/azure/__init__.py
       echo "__import__('pkg_resources').declare_namespace(__name__)" >> "$out/lib/${python.libPrefix}"/site-packages/azure/mgmt/__init__.py
@@ -1801,7 +1801,7 @@ in {
       url = mirror://pypi/a/azure-storage/azure-storage-0.20.3.zip;
       sha256 = "06bmw6k2000kln5jwk5r9bgcalqbyvqirmdh9gq4s6nb4fv3c0jb";
     };
-    propagatedBuildInputs = with self; [ azure-common futures dateutil requests2 ];
+    propagatedBuildInputs = with self; [ azure-common futures dateutil requests ];
     postInstall = ''
       echo "__import__('pkg_resources').declare_namespace(__name__)" >> "$out/lib/${python.libPrefix}"/site-packages/azure/__init__.py
     '';
@@ -1820,7 +1820,7 @@ in {
       url = mirror://pypi/a/azure-servicemanagement-legacy/azure-servicemanagement-legacy-0.20.1.zip;
       sha256 = "17dwrp99sx5x9cm4vldkaxhki9gbd6dlafa0lpr2n92xhh2838zs";
     };
-    propagatedBuildInputs = with self; [ azure-common requests2 ];
+    propagatedBuildInputs = with self; [ azure-common requests ];
     postInstall = ''
       echo "__import__('pkg_resources').declare_namespace(__name__)" >> "$out/lib/${python.libPrefix}"/site-packages/azure/__init__.py
     '';
@@ -2090,7 +2090,7 @@ in {
       sha256 = "0vw4d53jbbb2kdl7l891h8iyxklqcd6ldvgcyhw9hl40ljdhv1wz";
     };
 
-    propagatedBuildInputs = [ self.requests2 ];
+    propagatedBuildInputs = [ self.requests ];
 
     doCheck = false;
 
@@ -2523,7 +2523,7 @@ in {
     };
 
     buildInputs = with self; [ pillow tox mock six nose ];
-    propagatedBuildInputs = with self; [ requests2 decorator simplejson ];
+    propagatedBuildInputs = with self; [ requests decorator simplejson ];
 
     meta = {
       description = "The Datadog Python library ";
@@ -2565,7 +2565,7 @@ in {
       sha256 = "1bkqhlzigy656pam0znp2ddp1y5sqzyhw3c4fyy58spcafldq4j6";
     };
     buildInputs = with self; [ pytest ];
-    propagatedBuildInputs = with self; [ requests2 lxml pbr ];
+    propagatedBuildInputs = with self; [ requests lxml pbr ];
     # prompt_toolkit doesn't work on 3.5 on OSX.
     doCheck = !isPy35;
 
@@ -2609,7 +2609,7 @@ in {
       sha256 = "0fs7a4cf4f12mjhcjd5vfh0f3ixcy2nawzxpgsfr3ahf0rg7ppx5";
     };
 
-    propagatedBuildInputs = with self; [ cookies mock requests2 six ];
+    propagatedBuildInputs = with self; [ cookies mock requests six ];
 
     doCheck = false;
 
@@ -2732,7 +2732,7 @@ in {
        sha256 = "d881e21ec7ebfa006cfca6d10a5b7229aa59990568f8c6b8e3364769fa38b6f6";
     };
 
-    propagatedBuildInputs = [ self.requests2 ];
+    propagatedBuildInputs = [ self.requests ];
 
     # No tests
     doCheck = false;
@@ -2793,7 +2793,7 @@ in {
       psutil
       pymongo
       pyyaml
-      requests2
+      requests
       sqlalchemy
       tables
       toolz
@@ -2983,7 +2983,7 @@ in {
       werkzeug
       itsdangerous
       dateutil
-      requests2
+      requests
       six
       pygments
       pystache
@@ -3023,7 +3023,7 @@ in {
     '';
 
     buildInputs = [ self.nose self.mock ];
-    propagatedBuildInputs = [ self.requests2 self.httpretty ];
+    propagatedBuildInputs = [ self.requests self.httpretty ];
 
     meta = {
       homepage = https://github.com/boto/boto;
@@ -3088,7 +3088,7 @@ in {
 
     propagatedBuildInputs =
       [ self.dateutil
-        self.requests2
+        self.requests
         self.jmespath
       ];
 
@@ -3167,7 +3167,7 @@ in {
 
     buildInputs = with self; [ mock unittest2 nose /* jira megaplan */ ];
     propagatedBuildInputs = with self; [
-      twiggy requests2 offtrac bugzilla taskw dateutil pytz keyring six
+      twiggy requests offtrac bugzilla taskw dateutil pytz keyring six
       jinja2 pycurl dogpile_cache lockfile click pyxdg
     ];
 
@@ -3213,7 +3213,7 @@ in {
     patches = [ ../development/python-modules/bugzilla/checkPhase-fix-cookie-compare.patch ];
 
     buildInputs = with self; [ pep8 coverage logilab_common ];
-    propagatedBuildInputs = [ self.requests2 ];
+    propagatedBuildInputs = [ self.requests ];
 
     preCheck = ''
       mkdir -p check-phase
@@ -3257,7 +3257,7 @@ in {
       sha256 = "0l3a7iyk596x6pvzg7604lzzi012qszr804fqn6f517zcy1xz23j";
     };
 
-    propagatedBuildInputs = [ self.requests2 self.py ];
+    propagatedBuildInputs = [ self.requests self.py ];
 
     meta = {
       homepage = https://bitbucket.org/hpk42/devpi;
@@ -3633,7 +3633,7 @@ in {
       sed -i 's/==/>=/' requirements.txt
     '';
 
-    propagatedBuildInputs = with self; [ docopt requests2 pygments ];
+    propagatedBuildInputs = with self; [ docopt requests pygments ];
 
     # Error when running tests:
     # No local packages or download links found for requests
@@ -4103,7 +4103,7 @@ in {
       sha256 = "0vfyr499sbc4nnhhijp2lznyj507nnak95bvv9w8y78ngxggskbh";
     };
 
-    buildInputs = with self; [ requests2 six pytest ];
+    buildInputs = with self; [ requests six pytest ];
 
     # No tests distributed. https://github.com/cablehead/python-consul/issues/133
     doCheck = false;
@@ -4403,7 +4403,7 @@ in {
 
     propagatedBuildInputs = with self; [
       pbr stevedore netaddr iso8601 six oslo-i18n oslo-utils Babel pyyaml eventlet
-      requests2 urllib3 oslo-concurrency suds-jurko
+      requests urllib3 oslo-concurrency suds-jurko
     ];
     buildInputs = with self; [
       bandit oslosphinx coverage testtools testscenarios testrepository mock
@@ -4421,7 +4421,7 @@ in {
     };
 
     propagatedBuildInputs = with self; [
-      pbr argparse requests2 six keystoneclient cliff oslo-i18n oslo-serialization
+      pbr argparse requests six keystoneclient cliff oslo-i18n oslo-serialization
       oslo-utils
     ];
     buildInputs = with self; [
@@ -4471,7 +4471,7 @@ in {
     buildInputs = with self; [
       pbr testtools testscenarios testrepository requests-mock fixtures ];
     propagatedBuildInputs = with self; [
-      Babel argparse prettytable requests2 simplejson six iso8601
+      Babel argparse prettytable requests simplejson six iso8601
       keystoneclient tempest-lib ];
 
     # TODO: check if removing this test is really harmless
@@ -4582,7 +4582,7 @@ in {
 
     propagatedBuildInputs = with self; [
      pbr six Babel cliff os-client-config oslo-config oslo-i18n oslo-utils
-     glanceclient keystoneclient novaclient cinderclient neutronclient requests2
+     glanceclient keystoneclient novaclient cinderclient neutronclient requests
      stevedore cliff-tablib
     ];
     buildInputs = with self; [
@@ -5203,7 +5203,7 @@ in {
     version = "1.1.0";
 
     buildInputs = with self; [ pytest ];
-    propagatedBuildInputs = with self; [ setuptools-git pytest-shutil pytest-fixture-config psutil requests2 ];
+    propagatedBuildInputs = with self; [ setuptools-git pytest-shutil pytest-fixture-config psutil requests ];
 
     meta = {
       description = "Extensible server fixures for py.test";
@@ -5316,7 +5316,7 @@ in {
     };
 
     propagatedBuildInputs = with self; [ werkzeug ];
-    buildInputs = with self; [ pytest six requests2 ];
+    buildInputs = with self; [ pytest six requests ];
 
     checkPhase = ''
       py.test
@@ -5554,7 +5554,7 @@ in {
   digital-ocean = buildPythonPackage rec {
     name = "python-digitalocean-1.10.1";
 
-    propagatedBuildInputs = with self; [ requests2 ];
+    propagatedBuildInputs = with self; [ requests ];
 
     # Package doesn't distribute tests.
     doCheck = false;
@@ -5699,7 +5699,7 @@ in {
 
     buildInputs = with self; [ mock ];
 
-    propagatedBuildInputs = with self; [ requests2 six urllib3 ];
+    propagatedBuildInputs = with self; [ requests six urllib3 ];
 
     meta = {
       description = "Persistent cache for requests library";
@@ -6047,7 +6047,7 @@ in {
       sha256 = "0a3616a818dd9fa61a61c3d9731d176e9123130d1b1b97a6beee63b4c72306b7";
     };
 
-    propagatedBuildInputs = with self; [ oauth2 requests2 ];
+    propagatedBuildInputs = with self; [ oauth2 requests ];
 
     meta = {
       description = "Official Python API client for Discogs";
@@ -6156,7 +6156,7 @@ in {
     doCheck = false; # requires redis server
     propagatedBuildInputs = with self; [
       setuptools docker_registry_core blinker flask gevent gunicorn pyyaml
-      requests2 rsa sqlalchemy setuptools backports_lzma m2crypto
+      requests rsa sqlalchemy setuptools backports_lzma m2crypto
     ];
 
     patchPhase = "> requirements/main.txt";
@@ -6253,7 +6253,7 @@ in {
       sha256 ="0ams289qcgna96aak96jbz6wybs6qb95h2gn8lb4lmx2p5sq4q56";
     };
 
-    propagatedBuildInputs = with self; [ requests2 six ];
+    propagatedBuildInputs = with self; [ requests six ];
 
     meta = {
       description = "Digital Ocean API python wrapper";
@@ -6326,7 +6326,7 @@ in {
       sha256 = "f65c12bd97f09e29a951bc7cb30a74e005fc4b2f8bb48778796be3f73866b173";
     };
 
-    propagatedBuildInputs = with self; [ requests2 urllib3 mock setuptools ];
+    propagatedBuildInputs = with self; [ requests urllib3 mock setuptools ];
 
     meta = {
       description = "A Python library for Dropbox's HTTP-based Core and Datastore APIs";
@@ -6424,7 +6424,7 @@ in {
     # Check is disabled because running them destroy the content of the local cluster!
     # https://github.com/elasticsearch/elasticsearch-py/tree/master/test_elasticsearch
     doCheck = false;
-    propagatedBuildInputs = with self; [ urllib3 requests2 ];
+    propagatedBuildInputs = with self; [ urllib3 requests ];
     buildInputs = with self; [ nosexcover mock ];
 
     meta = {
@@ -6506,7 +6506,7 @@ in {
       sed -i -e '13,14d;37d' setup.py
     '';
 
-    propagatedBuildInputs = with self; [ simplejson pytz requests2 ];
+    propagatedBuildInputs = with self; [ simplejson pytz requests ];
 
     # No proper tests are available
     doCheck = false;
@@ -6811,7 +6811,7 @@ in {
     };
 
     disabled = !isPy3k;
-    propagatedBuildInputs = with self; [ docutils requests2 requests_download zipfile36];
+    propagatedBuildInputs = with self; [ docutils requests requests_download zipfile36];
 
     meta = {
       description = "A simple packaging tool for simple packages";
@@ -7084,7 +7084,7 @@ in {
       mutagen
       protobuf3_0
       setuptools
-      requests2
+      requests
       dateutil
       proboscis
       mock
@@ -7255,7 +7255,7 @@ in {
       pyasn1
       pycparser
       pycryptodome
-      requests2
+      requests
       six
     ];
 
@@ -7279,7 +7279,7 @@ in {
     };
     buildInputs = with self; [ pytest responses ];
 
-    propagatedBuildInputs = with self; [ docopt flask markdown path-and-address pygments requests2 ];
+    propagatedBuildInputs = with self; [ docopt flask markdown path-and-address pygments requests ];
 
     checkPhase = ''
       export PATH="$PATH:$out/bin"
@@ -7544,7 +7544,7 @@ in {
       sha256 = "0cdmzpk5wvi6fyfmmn96vynqkb1p59wjqjdijhm1ixf7bfl9r126";
     };
 
-    propagatedBuildInputs = with self; [ six requests2 ];
+    propagatedBuildInputs = with self; [ six requests ];
 
     meta = {
       description = "A python client library for the IPFS API";
@@ -7646,7 +7646,7 @@ in {
     '';
 
     buildInputs = with self; [ pytest ];
-    propagatedBuildInputs = with self; [ six clint pyyaml docopt requests2 jsonpatch args ];
+    propagatedBuildInputs = with self; [ six clint pyyaml docopt requests jsonpatch args ];
 
     meta = with stdenv.lib; {
       description = "A python wrapper for the various Internet Archive APIs";
@@ -8375,7 +8375,7 @@ in {
     propagatedBuildInputs = with self; [
       ansicolors beautifulsoup4 cffi coverage docutils fasteners futures
       isort lmdb markdown mock packaging pathspec pep8 pex psutil pyflakes
-      pygments pystache pytestcov pytest pywatchman requests2 scandir
+      pygments pystache pytestcov pytest pywatchman requests scandir
       setproctitle setuptools six thrift wheel twitter-common-dirutil
       twitter-common-confluence twitter-common-collections
     ];
@@ -8409,7 +8409,7 @@ in {
 
     propagatedBuildInputs = with self; [
       twitter-common-collections setproctitle setuptools six ansicolors
-      packaging pathspec scandir twitter-common-dirutil psutil requests2
+      packaging pathspec scandir twitter-common-dirutil psutil requests
       pystache pex docutils markdown pygments twitter-common-confluence
       fasteners coverage pywatchman futures cffi
     ];
@@ -9495,7 +9495,7 @@ in {
       rev = version;
       sha256 = "1mnl0rfbnimcpp7q9hva0x9jfa58j4nc27r9kvaii8869kzssw48";
     };
-    propagatedBuildInputs = with self; [ requests2 ];
+    propagatedBuildInputs = with self; [ requests ];
     prePatch = ''
       sed -i -e "s|\[\"acpi\"|\[\"${pkgs.acpi}/bin/acpi\"|" py3status/modules/battery_level.py
       sed -i -e "s|notify-send|${pkgs.libnotify}/bin/notify-send|" py3status/modules/battery_level.py
@@ -10457,7 +10457,7 @@ in {
       pygments
       simplejson
       dateutil
-      requests2
+      requests
       sqlparse
       jinja2
       autopep8
@@ -11534,7 +11534,7 @@ in {
       sha256 = "ddce23a2dd0abba6d19775e9bf7ba64e184b15a0e7163e65f62af63354193f63";
     };
 
-    buildInputs = with self; stdenv.lib.optionals doCheck [coverage ddt nose pyyaml requests2 testtools];
+    buildInputs = with self; stdenv.lib.optionals doCheck [coverage ddt nose pyyaml requests testtools];
     propagatedBuildInputs = with self; [ six python_mimeparse ];
 
     # The travis build fails since the migration from multiprocessing to threading for hosting the API under test.
@@ -11555,7 +11555,7 @@ in {
       sha256 = "93325e13706594933a9afb0d4f0b0748134494299038f07df41152baf6f89f4c";
     };
 
-    propagatedBuildInputs = with self; [ falcon requests2 ];
+    propagatedBuildInputs = with self; [ falcon requests ];
 
     # tests are not shipped in the tarball
     doCheck = false;
@@ -12101,7 +12101,7 @@ in {
 
     buildInputs = with self; [ unittest2 pytest mock betamax betamax-matchers ];
 
-    propagatedBuildInputs = with self; [ requests2 pyopenssl uritemplate_py
+    propagatedBuildInputs = with self; [ requests pyopenssl uritemplate_py
       ndg-httpsclient requests_toolbelt pyasn1 ];
 
     postPatch = ''
@@ -12494,7 +12494,7 @@ in {
       sha256 = "0qxa4g1ij1bj27mbp8l54lcr7d5krkb2rayisc6shkpf2b51ip4c";
     };
 
-    propagatedBuildInputs = with self; [ requests2 ];
+    propagatedBuildInputs = with self; [ requests ];
   };
 
   hypothesis = callPackage ../development/python-modules/hypothesis.nix { };
@@ -12597,7 +12597,7 @@ in {
       sha256 = "1nmdk6d89z14x3wg4yxywlxjdip16zc8bqnfb471z1365mr74jj7";
     };
 
-    buildInputs = with self; [ tornado requests2 httplib2 sure nose coverage certifi ];
+    buildInputs = with self; [ tornado requests httplib2 sure nose coverage certifi ];
 
     propagatedBuildInputs = with self; [ urllib3 ];
 
@@ -12712,7 +12712,7 @@ in {
 
     # ImportError: No module named tests
     doCheck = false;
-    propagatedBuildInputs = with self; [ requests2 dateutil pytz six ];
+    propagatedBuildInputs = with self; [ requests dateutil pytz six ];
 
     meta = {
       description = "Python client for InfluxDB";
@@ -13439,7 +13439,7 @@ in {
     doCheck = false;
 
     propagatedBuildInputs = with self; [
-      click watchdog exifread requests2 mistune inifile Babel jinja2
+      click watchdog exifread requests mistune inifile Babel jinja2
       flask pyopenssl ndg-httpsclient pkgs.glibcLocales
     ];
   };
@@ -13542,7 +13542,7 @@ in {
       sha256 = "db3c2a7fab8966d903a63f16c515bff241533e4ef2d746aa7aae4a49bba5e573";
     };
 
-    propagatedBuildInputs = with self; [ requests2 ];
+    propagatedBuildInputs = with self; [ requests ];
 
     meta = {
       homepage = "https://github.com/ghickman/linode";
@@ -13610,7 +13610,7 @@ in {
       sha256 = "c9ca6fdfe6a6fb187a3d54ddf9b1518196348e8f20537f0a14ca81a264ffafa2";
     };
 
-    propagatedBuildInputs = [ self.msgpack self.requests2 self.flask self.gevent self.pyzmq ];
+    propagatedBuildInputs = [ self.msgpack self.requests self.flask self.gevent self.pyzmq ];
     buildInputs = [ self.mock self.unittest2 ];
 
     meta = {
@@ -13999,7 +13999,7 @@ in {
       sha256 = "02jkwly4gw1jqm55l4wwn0j0ggnysx55inw9j96bif5l49z5cacd";
     };
 
-    propagatedBuildInputs = with self; [ requests2 beautifulsoup4 six ];
+    propagatedBuildInputs = with self; [ requests beautifulsoup4 six ];
 
     meta = {
       description = "A Python library for automating interaction with websites";
@@ -14079,7 +14079,7 @@ in {
     buildInputs = with self; [ pyflakes pep8 ];
     propagatedBuildInputs = with self; [
       django_1_6 filebrowser_safe grappelli_safe bleach tzlocal beautifulsoup4
-      requests2 requests_oauthlib future pillow
+      requests requests_oauthlib future pillow
     ];
 
     # Tests Fail Due to Syntax Warning, Fixed for v3.1.11+
@@ -14240,7 +14240,7 @@ in {
 
     buildInputs = with self; [
       pkgs.libjpeg pkgs.freetype pkgs.zlib pkgs.glibcLocales
-      pillow twitter pyfiglet requests2 arrow dateutil pysocks
+      pillow twitter pyfiglet requests arrow dateutil pysocks
       pocket
     ];
 
@@ -14262,7 +14262,7 @@ in {
     };
 
     buildInputs = with self; [
-      requests2
+      requests
     ];
 
     meta = {
@@ -14487,7 +14487,7 @@ in {
 
     propagatedBuildInputs = with self; [
       # Main dependencies
-      jinja2 werkzeug flask requests2 six boto httpretty xmltodict
+      jinja2 werkzeug flask requests six boto httpretty xmltodict
       # For tests
       nose sure boto3 freezegun
     ];
@@ -14867,7 +14867,7 @@ in {
 
     buildInputs = with self; [ mock responses pytestcov pytest pytestcache pytestpep8 coverage ];
 
-    propagatedBuildInputs = with self; [ six requests2 requests_oauthlib ];
+    propagatedBuildInputs = with self; [ six requests requests_oauthlib ];
 
     checkPhase = ''
       py.test
@@ -15733,7 +15733,7 @@ in {
       sha256 = "0yjxwisxpxy3vpnqk9nw5k3db3xx6wyf6sk1px9m94s30glcq2cc";
     };
 
-    propagatedBuildInputs = with self; [ appdirs pyyaml requests2 dbus-python emoji sleekxmpp mock ];
+    propagatedBuildInputs = with self; [ appdirs pyyaml requests dbus-python emoji sleekxmpp mock ];
 
     meta = {
       description = "A utility for sending notifications, on demand and when commands finish";
@@ -15980,7 +15980,7 @@ in {
 
     buildInputs = [ pkgs.makeWrapper ];
 
-    propagatedBuildInputs = with self; [ pkgs.rtmpdump pycrypto requests2 ]
+    propagatedBuildInputs = with self; [ pkgs.rtmpdump pycrypto requests ]
       ++ optionals isPy26 [ singledispatch futures argparse ]
       ++ optionals isPy27 [ singledispatch futures ]
       ++ optionals isPy33 [ singledispatch ];
@@ -16374,7 +16374,7 @@ in {
     doCheck = false;
 
     propagatedBuildInputs = with self; [
-      pbr requests2 sphinx_1_2
+      pbr requests sphinx_1_2
     ];
   };
 
@@ -16670,7 +16670,7 @@ in {
     };
 
     propagatedBuildInputs = with self; [
-      six Babel simplejson requests2 keystoneclient prettytable argparse pbr
+      six Babel simplejson requests keystoneclient prettytable argparse pbr
     ];
     buildInputs = with self; [
       testrepository requests-mock
@@ -16696,7 +16696,7 @@ in {
     };
 
     propagatedBuildInputs = with self; [
-      pbr six simplejson keystoneclient requests2 oslo-utils oslo-serialization
+      pbr six simplejson keystoneclient requests oslo-utils oslo-serialization
       oslo-i18n netaddr iso8601 cliff argparse
     ];
     buildInputs = with self; [
@@ -16814,7 +16814,7 @@ in {
    };
 
    propagatedBuildInputs = with self; [
-     oslo-i18n oslo-utils six requests2 keystoneclient prettytable Babel pbr
+     oslo-i18n oslo-utils six requests keystoneclient prettytable Babel pbr
      argparse warlock
    ];
    buildInputs = with self; [
@@ -17083,7 +17083,7 @@ in {
     };
 
     propagatedBuildInputs = with self; [
-      pbr requests2 futures six
+      pbr requests futures six
     ];
     buildInputs = with self; [
       testtools testrepository mock
@@ -17322,7 +17322,7 @@ in {
     };
 
     propagatedBuildInputs = with self; [
-      requests2 oslo-config oslo-i18n oslo-serialization oslo-utils six
+      requests oslo-config oslo-i18n oslo-serialization oslo-utils six
     ];
     buildInputs = with self; [
       oslosphinx httpretty oslotest
@@ -17575,7 +17575,7 @@ in {
 
     buildInputs = with self; [ pbr testtools testresources testrepository mock
                                pep8 fixtures mox3 requests-mock ];
-    propagatedBuildInputs = with self; [ argparse iso8601 requests2 six stevedore
+    propagatedBuildInputs = with self; [ argparse iso8601 requests six stevedore
                                          webob oslo-config ];
     patchPhase = ''
       sed -i 's@python@${python.interpreter}@' .testr.conf
@@ -17596,7 +17596,7 @@ in {
     '';
 
     buildInputs = with self; [ pbr testtools testrepository mock ];
-    propagatedBuildInputs = with self; [ six requests2 ];
+    propagatedBuildInputs = with self; [ six requests ];
   };
 
   mox3 = buildPythonPackage rec {
@@ -18433,7 +18433,7 @@ in {
       sha256 = "f3a646871f9baed05f336a32576edaab90abf0737d8adb54f2acb7bcad42a65f";
      };
 
-     propagatedBuildInputs = with self; [ click_5 requests2 bottle pyserial lockfile colorama];
+     propagatedBuildInputs = with self; [ click_5 requests bottle pyserial lockfile colorama];
 
      meta = with stdenv.lib; {
      description = "An open source ecosystem for IoT development";
@@ -18784,7 +18784,7 @@ in {
     };
 
     propagatedBuildInputs = with self; [
-      requests2
+      requests
       decorator
       flake8
       mock
@@ -19008,7 +19008,7 @@ in {
       sha256 = "0117039cb116af245e6866e8e8bf3c9c8b2853ad087142bd0c2dfc0acc09d452";
     };
 
-    propagatedBuildInputs = with self; [ requests2 audioread ];
+    propagatedBuildInputs = with self; [ requests audioread ];
 
     patches = [ ../development/python-modules/pyacoustid-py3.patch ];
 
@@ -19119,7 +19119,7 @@ in {
 
     propagatedBuildInputs = with self; [
       repoze_who paste cryptography pycrypto pyopenssl ipaddress six cffi idna
-      enum34 pytz setuptools zope_interface dateutil requests2 pyasn1 webob decorator pycparser
+      enum34 pytz setuptools zope_interface dateutil requests pyasn1 webob decorator pycparser
       defusedxml
     ];
     buildInputs = with self; [
@@ -21651,8 +21651,6 @@ in {
     };
   };
 
-  requests = self.requests2;
-
   # Remove before release of 17.09
   requests_1 = buildPythonPackage rec {
     name = "requests-1.2.3";
@@ -21669,7 +21667,10 @@ in {
     };
   };
 
-  requests2 = buildPythonPackage rec {
+  requests2 = throw "requests2 has been deprecated. Use requests instead.";
+
+  # use requests, not requests_2
+  requests = buildPythonPackage rec {
     name = "requests-${version}";
     version = "2.13.0";
 
@@ -21701,7 +21702,7 @@ in {
       sha256 = "07832a93314bcd619aaeb08611ae245728e66672efb930bc2a300a115a47dab7";
     };
 
-    propagatedBuildInputs = with self; [ requests2 ];
+    propagatedBuildInputs = with self; [ requests ];
 
     meta = {
       description = "Download files using requests and save them to a target path";
@@ -21722,7 +21723,7 @@ in {
       sha256 = "16grklnbgcfwqj3f39gw7fc9afi7xlp9gm7x8w6mi81dzhdxf50y";
     };
 
-    propagatedBuildInputs = with self; [ requests2 ];
+    propagatedBuildInputs = with self; [ requests ];
 
     buildInputs = with self; [ betamax mock pytest ];
 
@@ -21932,7 +21933,7 @@ in {
       sha256 = "1aij66qg9j5j4vzyh64nbg72y7pcafgjddxsi865racsay43xfqg";
     };
 
-    propagatedBuildInputs = with self; [ requests2 ];
+    propagatedBuildInputs = with self; [ requests ];
     # no tests in tarball
     doCheck = false;
 
@@ -22006,7 +22007,7 @@ in {
     };
 
     propagatedBuildInputs = with self; [
-      requests2
+      requests
     ];
     buildInputs = with self; [
 
@@ -22335,7 +22336,7 @@ in {
     };
 
     buildInputs = with self; [ unittest2 ];
-    propagatedBuildInputs = with self; [ robotframework lxml requests2 ];
+    propagatedBuildInputs = with self; [ robotframework lxml requests ];
 
     meta = {
       description = "Robot Framework keyword library wrapper around the HTTP client library requests";
@@ -23625,7 +23626,7 @@ in {
       sha256 = "0zdz8lw545cd3a34cpib7mdwnad83gr2mrrxyj3v74h4zhwabhmg";
     };
 
-    propagatedBuildInputs = with self; [ six requests2 mock unittest2 ];
+    propagatedBuildInputs = with self; [ six requests mock unittest2 ];
 
     # FIXME
     doCheck = false;
@@ -24170,7 +24171,7 @@ in {
       sqlalchemy
       whoosh
       imagesize
-      requests2
+      requests
     ];
 
     # https://github.com/NixOS/nixpkgs/issues/22501
@@ -24980,7 +24981,7 @@ in {
         oslotest pep8 ];
     propagatedBuildInputs = with self; [
         oslo-serialization oslo-config oslo-i18n oslo-utils
-        Babel argparse prettytable requests2 six iso8601 stevedore
+        Babel argparse prettytable requests six iso8601 stevedore
         netaddr debtcollector bandit webob mock pycrypto ];
 
     patchPhase = ''
@@ -25018,7 +25019,7 @@ in {
     ];
     propagatedBuildInputs = with self; [
       pbr Babel oslo-config oslo-context oslo-i18n oslo-serialization oslo-utils
-      requests2 six webob keystoneclient pycadf oslo-messaging
+      requests six webob keystoneclient pycadf oslo-messaging
     ];
 
     # lots of "unhashable type" errors
@@ -25500,7 +25501,7 @@ in {
     };
 
     doCheck = false;
-    propagatedBuildInputs = with self; [ requests2 six requests_oauthlib ];
+    propagatedBuildInputs = with self; [ requests six requests_oauthlib ];
 
     meta = {
       homepage = "https://github.com/tweepy/tweepy";
@@ -25677,7 +25678,7 @@ in {
       sha256 = "68b663691a947b844f92853c992d42bb68b6333bffc9ab7f661346b001c1da82";
     };
 
-    propagatedBuildInputs = with self; [ clint pkginfo requests2 requests_toolbelt ];
+    propagatedBuildInputs = with self; [ clint pkginfo requests requests_toolbelt ];
 
     # Requires network
     doCheck = false;
@@ -25889,7 +25890,7 @@ in {
       sha256 = "681bc7c26cffd1564eb6f0f3170d975a31c2a9f2224a32f80fe954232b86f173";
     };
 
-    propagatedBuildInputs = with self; [ requests2 ];
+    propagatedBuildInputs = with self; [ requests ];
 
     doCheck = false;
 
@@ -26189,7 +26190,7 @@ EOF
       sha256 = "991bc2f1dc824c63e9b399f9e8606deded92a52378d0e449f258807d7556b039";
     };
 
-    propagatedBuildInputs = with self; [ requests2 six];
+    propagatedBuildInputs = with self; [ requests six];
 
     # No tests included
     doCheck = false;
@@ -26213,7 +26214,7 @@ EOF
         sha256 = "1qjvvr2v9gfnwskdl0ayazpcmiyw9zlgnijnhgq9mcri5gq9jw5h";
     };
 
-    propagatedBuildInputs = with self; [ requests2 ];
+    propagatedBuildInputs = with self; [ requests ];
 
     # Tests disabled. They fail because they try to access the network
     doCheck = false;
@@ -26432,7 +26433,7 @@ EOF
     LC_ALL = "en_US.UTF-8";
 
     propagatedBuildInputs = with self; [ itsdangerous ];
-    buildInputs = with self; [ pytest requests2 pkgs.glibcLocales ];
+    buildInputs = with self; [ pytest requests pkgs.glibcLocales ];
 
 
 
@@ -27406,7 +27407,7 @@ EOF
   tunigo = buildPythonPackage rec {
     name = "tunigo-${version}";
     version = "1.0.0";
-    propagatedBuildInputs = with self; [ requests2 ];
+    propagatedBuildInputs = with self; [ requests ];
 
     src = pkgs.fetchFromGitHub {
       owner = "trygveaa";
@@ -27994,7 +27995,7 @@ EOF
       url = "mirror://pypi/t/${pname}/${name}.tar.gz";
       sha256 = "0kkxxd17ar5gyjkz9yrrdr15a64qw6ym60ndi0zbwx2s634yfafw";
     };
-    propagatedBuildInputs = with self; [ twisted requests2 cryptography ];
+    propagatedBuildInputs = with self; [ twisted requests cryptography ];
 
     # Require network access
     doCheck = false;
@@ -28396,7 +28397,7 @@ EOF
     '';
 
     propagatedBuildInputs = with self; [
-      pyyaml lxml grequests flaskbabel flask requests2
+      pyyaml lxml grequests flaskbabel flask requests
       gevent speaklater Babel pytz dateutil pygments
       pyasn1 pyasn1-modules ndg-httpsclient certifi pysocks
     ];
@@ -28438,7 +28439,7 @@ EOF
     # No tests in archive
     doCheck = false;
 
-    propagatedBuildInputs = with self; [ requests2 gevent ];
+    propagatedBuildInputs = with self; [ requests gevent ];
 
     meta = {
       description = "Asynchronous HTTP requests";
@@ -28983,7 +28984,7 @@ EOF
 
     setupPyBuildFlags = ["--qt" "--xdg"];
 
-    propagatedBuildInputs = with self; [ pillow prettytable pyyaml dateutil gdata requests2 mechanize feedparser lxml pkgs.gnupg pyqt4 pkgs.libyaml simplejson cssselect futures pdfminer termcolor ];
+    propagatedBuildInputs = with self; [ pillow prettytable pyyaml dateutil gdata requests mechanize feedparser lxml pkgs.gnupg pyqt4 pkgs.libyaml simplejson cssselect futures pdfminer termcolor ];
 
     meta = {
       homepage = http://weboob.org;
@@ -29520,7 +29521,7 @@ EOF
       sha256 = "0fcc78b8dfc87237942aad2a8be54dbc08bc4afceaa7f6897f3d894e7d4bfd22";
     };
 
-    propagatedBuildInputs = with self; [ pytz requests2 ];
+    propagatedBuildInputs = with self; [ pytz requests ];
 
     buildInputs = with self; [ coverage mock nose unittest2 ];
 
@@ -29844,7 +29845,7 @@ EOF
     version = "0.4.5";
     doCheck = false; #test needs packages too explicit
     buildInputs = with self; [ d2to1 ];
-    propagatedBuildInputs = with self; [ requests2 ];
+    propagatedBuildInputs = with self; [ requests ];
 
     src = pkgs.fetchurl {
       url = "mirror://pypi/o/ovh/ovh-${version}.tar.gz";
@@ -30322,7 +30323,7 @@ EOF
       dateutil
       inflection
       more-itertools
-      requests2
+      requests
       pandas
     ];
 
@@ -30926,7 +30927,7 @@ EOF
       sha256 = "063cbzp1fbdipv53gb0hnban1pg80pls0lbld98lhnykzkcb6vf0";
     };
 
-    propagatedBuildInputs = with self; [ websocket_client requests2 ];
+    propagatedBuildInputs = with self; [ websocket_client requests ];
   };
 
   tempora = buildPythonPackage rec {
@@ -30954,7 +30955,7 @@ EOF
       sha256 = "1sd8f3gihagaqd848dqy6xw457fa4f9bla1bfyni7fq3h76sjdzg";
     };
 
-    propagatedBuildInputs = with self; [ requests2 six dateutil ];
+    propagatedBuildInputs = with self; [ requests six dateutil ];
   };
 
   pivy = buildPythonPackage rec {
@@ -31002,7 +31003,7 @@ EOF
 
     buildInputs = [ python pkgs.makeWrapper ];
 
-    propagatedBuildInputs = with self; [ docopt requests2 smugpy ];
+    propagatedBuildInputs = with self; [ docopt requests smugpy ];
 
     installPhase = ''
       mkdir -p $out/bin $out/libexec
@@ -31137,7 +31138,7 @@ EOF
       url = "mirror://pypi/p/pwntools/${name}.tar.gz";
       sha256 = "1siyky6iq2b155sfjhx10yg2ihvjp2s3kr6i0n5z9v5pi0r7gc6d";
     };
-    propagatedBuildInputs = with self; [ Mako packaging pysocks pygments ROPGadget capstone paramiko pip psutil pyelftools pypandoc pyserial dateutil requests2 tox pkgs.pandoc ];
+    propagatedBuildInputs = with self; [ Mako packaging pysocks pygments ROPGadget capstone paramiko pip psutil pyelftools pypandoc pyserial dateutil requests tox pkgs.pandoc ];
 
     disabled = isPy3k;
diff --git a/pkgs/tools/networking/linkchecker/default.nix b/pkgs/tools/networking/linkchecker/default.nix
index d6906fdc554f9..78bdea475c4b9 100644
--- a/pkgs/tools/networking/linkchecker/default.nix
+++ b/pkgs/tools/networking/linkchecker/default.nix
@@ -5,7 +5,7 @@ python2Packages.buildPythonApplication rec {
   version = "9.3";
 
   buildInputs = with python2Packages ; [ pytest ];
-  propagatedBuildInputs = with python2Packages ; [ requests2 ] ++ [ gettext ];
+  propagatedBuildInputs = with python2Packages ; [ requests ] ++ [ gettext ];
 
   src = fetchurl {
     url = "mirror://pypi/L/LinkChecker/${name}.tar.gz";
@@ -13,7 +13,7 @@ python2Packages.buildPythonApplication rec {
   };
 
   # 1. upstream refuses to support ignoring robots.txt
   # 2. work around requests2 version detection - can be dropped >v9.3
   patches = [
     ./add-no-robots-flag.patch
     ./no-version-check.patch
@@ -13,7 +13,7 @@ python2Packages.buildPythonApplication rec {
 
   # 1. upstream refuses to support ignoring robots.txt
-  # 2. work around requests2 version detection - can be dropped >v9.3
+  # 2. work around requests version detection - can be dropped >v9.3
   patches = [
     ./add-no-robots-flag.patch